The NITF 2.0 label header (sarpy.io.general.nitf_elements.label)
================================================================

.. automodule:: sarpy.io.general.nitf_elements.label
    :members:
    :show-inheritance:
    :inherited-members:
